Build the create half of a block move
ztBlockMoveCreate.RdProduces create rows in the destination library from the given records. Items carrying imported files are refused: moving files needs the upload protocol, which this plan builder does not perform.
Examples
Records <- data.table::data.table(
itemKey = "OLD1",
payload = list(list(itemType = "book", title = "Reviewed book")),
hasFile = FALSE
)
ztBlockMoveCreate(Records, toLibrary = "5107760", collectionKey = "DEST")
#> action library itemKey payload
#> <char> <char> <char> <list>
#> 1: create 5107760 <NA> <list[3]>